#!/bin/sh
set -e

SELF=$(basename "$0")

# determine the absolute path the script is in
cd $(dirname "$0") > /dev/null
SCRIPTPATH=$(pwd -L)
cd - > /dev/null

# Find out if we're running on the camera or just locally in the module
# directory.
if [ $(expr match $(cat /etc/release) "JFFSID=") -gt 0 ]; then
    ON_CAMERA="true";
fi

application_name() {
    if [ -n "$ON_CAMERA" ]; then
        basename "$SCRIPTPATH"
    else
        # We are not running on the camera, so the application name is not
        # defined.  However return a placeholder string for the application
        # name which is useful for testing.
        echo "<appname>"
    fi
}

debug() {
    if [ -n "$DEBUG" ]; then echo "$SELF: $@"; fi
    if [ -n "$ON_CAMERA" ]; then
        logger "$(application_name)[0] $SELF: $@"
    fi
}

full_path() {
    if [ -n "$ON_CAMERA" ]; then
        echo "$SCRIPTPATH/$1"
    else
        echo "$1"
    fi
}

set_access_rights () {
    SET_ACL="set-access-rights.sh"

    if webserver_is_apache; then
        debug "Creating .htaccess file for Apache"
        create_htaccess
        return 0
    fi

    if [ -f $(full_path $SET_ACL) ]; then
        cmd="$(full_path $SET_ACL) $(application_name)"
        debug "Executing $cmd"
        $cmd
    else
        debug "Cannot find $SET_ACL to set the file access rights."
    fi
}

# Return true if the camera has Apache webserver installed
webserver_is_apache() {
    if type "httpd" > /dev/null; then
        return 0  # true
    else
        return 1  # false
    fi
}

# Create Apache access file out of our template
create_htaccess() {
    src=$(full_path ".htaccess.in")
    dst=$(full_path "html/.htaccess")

    debug "Copying $src -> $dst"
    cp -r $src $dst

    # add a time stamp at the end of the file
    echo "" >> $dst
    echo "# Created by $SELF on $(date)" >> $dst
}

# 2018-02-22 (SI): Ab Axis Firmware Version 7.x funktioniert die Umleitung über den gesetzten Parameter (root.Layout.OwnHomePagePath) nicht mehr.
# Hier wird eine Datei im Web-Server erstellt, welche die Umleitung dennoch möglich macht. Da die Datei nach Deinstallation des ACAP-Moduls nicht
# gelöscht wird, ist die Umleitung mit 'RewriteCond' an zwei Bedingen geknüpft. Die Erste prüft mit -d ob das Applikation-Verzeichnis vorhanden ist.
# Die zweite Bedingung prüft, ob die Applikation gerade läuft. Dafür legt das ACAP Modul eine Datei im tmp-Verzeichnis an, wenn die App gestartet
# wurde, bzw. löscht diese Datei wieder, wenn die App gestoppt wird. [JIRA VMB-868]
create_apache_redirect_conf() {
	if [ -d "/etc/apache2/conf.d/vhosts/all/" ]; then
		APACHE_CONF=/etc/apache2/conf.d/vhosts/all/$(application_name).conf
	else
		APACHE_CONF=/etc/apache2/conf.d/$(application_name).conf
	fi
	
	debug "Creating $APACHE_CONF"
	
	echo "RewriteCond /usr/local/packages/$(application_name) -d" > $APACHE_CONF
	echo "RewriteCond /tmp/$(application_name)-web-running -f" >> $APACHE_CONF
	echo "RewriteRule ^/$ /local/$(application_name)/configure.html [R,L]" >> $APACHE_CONF
}

# 2019-02-06 (SI): Mit Axis Firmware Version 8.30 wurden die Dateirechte auf der Kamera überarbeitet. Alles ist standardmäßig blokiert und ".htaccess"
# ist deaktiviert. Alternativ zu ".htaccess" können die Rechte im Apche-Verzeichnis mit höherer Priorität gesetzt werden. Die Rechtebelegung wurde in
# urls_ips....conf während release.py automatisch erzeugt und an das Modul angepasst. Wichtig ist auch, dass die von Axis angelegte Datei überschrieben
# wird. (Gleicher Dateiname, cp überschreibt die von Axis erstellte Datei) [JIRA IVM-2494]
create_apache_access_conf() {
	if [ -d "/etc/apache2/conf.d/vhosts/all/" ]; then
		APACHE_CONF=/etc/apache2/conf.d/vhosts/all/urls_$(application_name).conf
	else
		APACHE_CONF=/etc/apache2/conf.d/urls_$(application_name).conf
	fi
	
	debug "Creating $APACHE_CONF"
	cp urls_$(application_name).txt $APACHE_CONF
}

debug "begin"
set_access_rights
create_apache_redirect_conf
create_apache_access_conf
debug "end"
