#!/bin/sh

SELF=`basename $0`

# Find out if we're running on the camera or just locally in the module
# directory.
if [ $(expr match $(cat /etc/release) "JFFSID=") -gt 0 ]; then
    ON_CAMERA="true";
fi

module_name="$1"

debug() {
    if [ -n "$DEBUG" ]; then echo "$SELF: $@"; fi
    if [ -n "$ON_CAMERA" ]; then
        logger "$module_name[0] $SELF: $@"
    fi
}

# command line arguments arguments
if [ -z "$1" ] ; then
    debug "usage: $0 module_name"
    debug "$0: error: too few arguments"
    exit 1
fi

access_control_file() {
    if [ -n "$ON_CAMERA" ] ; then
        echo "/usr/local/packages/${module_name}/ACL.txt"
    else
        echo "ACL.txt"
    fi
}

capitalize_module_name() {
    # Ex. ipsintrusion --> Intrusion
    # Also remove 'ips' word from given module_name

    fullname=$(echo ${module_name} | sed 's/ips//g')
    # uppercase the first character
    first_letter=$(echo ${fullname} | cut -c1-1)
    first_letter=$(echo ${first_letter} | tr '[:lower:]' '[:upper:]')
    without_first_letter=$(echo ${fullname} | cut -c2-)
    fullname=${first_letter}${without_first_letter}

    echo ${fullname}
}

module_fullname=$(capitalize_module_name ${module_name})
acl_filename=$(access_control_file)

resolve_acl_data() {
    #$1 = resource
    #$2 = owner
    #$3 = group
    #$4 = octal_mode
    #$5 = package_type

    #debug "------------------------------------------------------------------"

    # Ignore entry for "dev" package type
    if [ "$5" = "dev" ] ; then
        #debug "Package type 'dev' is ignored:" $1
        return 0
    fi

    # Check that given owner exists
    is_exist=$(cat /etc/group | grep ^$2:)
    if [ "${is_exist}" = "" ] ; then
        debug "The owner '$2' does not exist"
        return 1
    fi

    # Check that given group exists
    is_exist=$(cat /etc/group | grep ^$3:)
    if [ "${is_exist}" = "" ] ; then
        debug "The group '$3' does not exist"
        return 1
    fi

    # Get local path
    # replace {module_fullname} by $module_fullname
    tmp1=$(echo "${1}" | sed -e "s/"{module_fullname}"/${module_fullname}/g")
    # replace /local/ by /usr/local/packages/
    tmp2=$(echo "${tmp1}" | sed -e "s/\/local\//\/usr\/local\/packages\//g")
    # replace {module_name} by $module_name/html
    local_file="$(echo "${tmp2}" | sed -e "s/"{module_name}"/${module_name}\/html/g")"

    # Update rights for each file
    files=$(ls `echo "${local_file}"` 2> /dev/null | wc -l)
    # remove spaces added in ACAP module!
    files=$(echo "${files}" | sed -e "s/ //g")
    if [ "$files" != "0" ] ; then
        debug "chown $2:$3 $local_file"
        chown $2:$3 $local_file
        debug "chmod $4 $local_file"
        chmod $4 $local_file
    else
        debug "File does not exist:" $local_file
    fi
}

parse_acl_file() {
    # Read ACL file
    IFS=" $(echo t | tr t \\t)
    "
    iteration=0
    while read resource owner group octal_mode package_type 
    do
        iteration=$((iteration+1))

        # ignore the header (first line of the file)
        if [ ${iteration} -eq 1 ] ; then
            continue
        fi

        # if empty line, read next lines
        if [ ! $resource ] ; then
            continue
        fi

        # if it is a comment
        first_letter=$(echo ${resource} | cut -c1-1)
        if [ $first_letter = \# ] ; then
            continue
        fi

        # stop in case of syntax error
        if [ ! $resource ] || 
           [ ! $owner ] || 
           [ ! $group ] ||
           [ ! $octal_mode ] ||
           [ ! $package_type ] ;
        then
            debug "Syntax error in file ACL.txt (line ${iteration})"
            exit 1
        fi

        # construct array 'resources' to use it in function resolve_acl_data()
        resources="$resource $owner $group $octal_mode $package_type"
        resolve_acl_data $resources
        
    done < ${acl_filename}
}

debug "Analytics Module: ${module_name} (${module_fullname})"
parse_acl_file
